==> eiffelstudio-18.11.10.2592.tar: F_code/C7/kl343.c <==
/*
 * Code for class KL_IMPORTED_ARRAY_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl343.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_IMPORTED_ARRAY_ROUTINES}.integer_array_ */
static EIF_REFERENCE F943_4676_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4676);
#define Result RTOSR(4676)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {1110,1006,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1110, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4676);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4676 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4676,F943_4676_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.boolean_array_ */
static EIF_REFERENCE F943_4677_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4677);
#define Result RTOSR(4677)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {1112,1039,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1112, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4677);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4677 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4677,F943_4677_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_ */
static EIF_REFERENCE F943_4678_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4678);
#define Result RTOSR(4678)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {1109,1086,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1109, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4678);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4678 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4678,F943_4678_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_routines */
static EIF_REFERENCE F943_4679_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4679);
#define Result RTOSR(4679)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {1109,1086,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1109, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4679);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4679 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4679,F943_4679_body,(Current));
}

void EIF_Minit343 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C7/kl343.c <==
/*
 * Code for class KL_IMPORTED_ARRAY_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl343.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_IMPORTED_ARRAY_ROUTINES}.integer_array_ */
static EIF_REFERENCE F943_4692_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4692);
#define Result RTOSR(4692)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1111,1009,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1111, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4692);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4692 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4692,F943_4692_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.boolean_array_ */
static EIF_REFERENCE F943_4693_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4693);
#define Result RTOSR(4693)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1113,1003,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1113, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4693);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4693 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4693,F943_4693_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_ */
static EIF_REFERENCE F943_4694_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4694);
#define Result RTOSR(4694)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1109,1086,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1109, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4694);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4694 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4694,F943_4694_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_routines */
static EIF_REFERENCE F943_4695_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4695);
#define Result RTOSR(4695)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1109,0xFF01,1086,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1109, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4695);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F943_4695 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4695,F943_4695_body,(Current));
}

void EIF_Minit343 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
